# Py-SQL-Learning

Py-SQL-Learning is a simple library to test and execute SQL scripts from python

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install -r requirements.txt
```
